Profiles and Writing Files
==========================

How to use profiles when opening files.

Like Python's built in ``open()`` function, ``rasterio.open()`` has two primary
arguments: a path (or URL) and a mode (
